Coverage report

# Coverage report: 11%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 1125 | 967 | 0 | 281 | 2 | 11%
D:\Ralf Gerlich\git\modypy\modypy\__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
D:\Ralf Gerlich\git\modypy\modypy\blocks\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
D:\Ralf Gerlich\git\modypy\modypy\blocks\aerodyn.py | 52 | 52 | 0 | 8 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\blocks\discont.py | 7 | 7 | 0 | 0 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\blocks\discrete.py | 15 | 15 | 0 | 0 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\blocks\elmech.py | 28 | 28 | 0 | 0 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\blocks\linear.py | 136 | 112 | 0 | 79 | 2 | 12%
D:\Ralf Gerlich\git\modypy\modypy\blocks\rigid.py | 55 | 55 | 0 | 2 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\blocks\sources.py | 4 | 1 | 0 | 0 | 0 | 75%
D:\Ralf Gerlich\git\modypy\modypy\linearization.py | 79 | 79 | 0 | 24 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\model\__init__.py | 4 | 0 | 0 | 0 | 0 | 100%
D:\Ralf Gerlich\git\modypy\modypy\model\events.py | 110 | 74 | 0 | 24 | 0 | 27%
D:\Ralf Gerlich\git\modypy\modypy\model\ports.py | 115 | 74 | 0 | 28 | 0 | 29%
D:\Ralf Gerlich\git\modypy\modypy\model\states.py | 28 | 16 | 0 | 4 | 0 | 38%
D:\Ralf Gerlich\git\modypy\modypy\model\system.py | 83 | 47 | 0 | 18 | 0 | 36%
D:\Ralf Gerlich\git\modypy\modypy\simulation.py | 222 | 222 | 0 | 82 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\steady_state.py | 170 | 170 | 0 | 12 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\utils\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
D:\Ralf Gerlich\git\modypy\modypy\utils\uiuc_db.py | 15 | 15 | 0 | 0 | 0 | 0%
D:\Ralf Gerlich\git\modypy\modypy\version.py | 1 | 0 | 0 | 0 | 0 | 100%

No items found using the specified filter.